==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/sr.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Коментари",
    "Edit comment" : "Измени коментар",
    "Delete comment" : "Обриши коментар",
    "New comment …" : "Нови коментар …",
    "Post" : "Објави",
    "Cancel" : "Откажи",
    "[Deleted user]" : "[Обрисан корисник]",
    "No comments yet, start the conversation!" : "Тренутно нема коментара. Започните дискусију",
    "More comments …" : "Преостали коментари …",
    "Save" : "Сачувај",
    "Allowed characters {count} of {max}" : "Дозвољених {count} знакова од {max}",
    "Error occurred while retrieving comment with ID {id}" : "Дошло је до грешке при прегледу коментара са идентификацијом {id}",
    "Error occurred while updating comment with id {id}" : "Дошло је до грешке при преправци коментара ознаке {id}",
    "Error occurred while posting comment" : "Дошло је до грешке при објави коментара",
    "_%n unread comment_::_%n unread comments_" : ["%nнепрочитани коментар","%nнепрочитана коментара ","%n непрочитаних коментара"],
    "Comment" : "Коментар",
    "You commented" : "Искоментарисали сте",
    "%1$s commented" : "%1$s коментарисао",
    "{author} commented" : "{author} коментарисао",
    "You commented on %1$s" : "Коментарисали сте на %1$s",
    "You commented on {file}" : "Коментаристали сте на {file}",
    "%1$s commented on %2$s" : "%1$s коментарисао на %2$s",
    "{author} commented on {file}" : "{author} коментарисао на {file}",
    "<strong>Comments</strong> for files" : "<strong>Коментари</strong> на фајлове",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Поменути сте у \"%s\", у коментару који је оставио корисник који је од тада избрисан",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Поменути сте на фајлу \"{file}\", у коментару који је оставио корисник који је од тада избрисан",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s Вас је поменуо у коментару на \"%2$s\"",
    "{user} mentioned you in a comment on “{file}”" : "{user} Вас је поменуо у коментару на “{file}”",
    "Files app plugin to add comments to files" : "Додатак апликацији за фајлове да додајете коментаре на фајлове",
    "Unknown user" : "Непознат корисник",
    "A (now) deleted user mentioned you in a comment on “%s”" : "(Сада) обрисани корисник Вас је поменуо у коментару на “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "(Сада) обрисани корисник Вас је поменуо у коментару на “{file}”"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-14.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/sr.js <==
OC.L10N.register(
    "comments",
    {
    "Edit comment" : "Измени коментар",
    "Delete comment" : "Обриши коментар",
    "New comment …" : "Нови коментар …",
    "Post" : "Објави",
    "Cancel" : "Откажи",
    "[Deleted user]" : "[Обрисан корисник]",
    "Comments" : "Коментари",
    "No comments yet, start the conversation!" : "Тренутно нема коментара. Започните дискусију",
    "More comments …" : "Преостали коментари …",
    "Save" : "Сачувај",
    "Allowed characters {count} of {max}" : "Дозвољених {count} знакова од {max}",
    "Error occurred while retrieving comment with ID {id}" : "Дошло је до грешке при прегледу коментара са идентификацијом {id}",
    "Error occurred while updating comment with id {id}" : "Дошло је до грешке при преправци коментара ознаке {id}",
    "Error occurred while posting comment" : "Дошло је до грешке при објави коментара",
    "_%n unread comment_::_%n unread comments_" : ["%nнепрочитани коментар","%nнепрочитана коментара ","%n непрочитаних коментара"],
    "Comment" : "Коментар",
    "You commented" : "Искоментарисали сте",
    "%1$s commented" : "%1$s коментарисао",
    "{author} commented" : "{author} коментарисао",
    "You commented on %1$s" : "Коментарисали сте на %1$s",
    "You commented on {file}" : "Коментаристали сте на {file}",
    "%1$s commented on %2$s" : "%1$s коментарисао на %2$s",
    "{author} commented on {file}" : "{author} коментарисао на {file}",
    "<strong>Comments</strong> for files" : "<strong>Коментари</strong> на фајлове",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Поменути сте на фајлу \"{file}\", у коментару који је оставио корисник који је од тада избрисан",
    "{user} mentioned you in a comment on “{file}”" : "{user} Вас је поменуо у коментару на “{file}”",
    "Files app plugin to add comments to files" : "Додатак апликацији за фајлове да додајете коментаре на фајлове",
    "Unknown user" : "Непознат корисник",
    "A (now) deleted user mentioned you in a comment on “%s”" : "(Сада) обрисани корисник Вас је поменуо у коментару на “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "(Сада) обрисани корисник Вас је поменуо у коментару на “{file}”",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s Вас је поменуо у коментару на \"%2$s\"",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Поменути сте у \"%s\", у коментару који је оставио корисник који је од тада избрисан"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
